@@ -7,6 +7,8 @@ global GLOBALS
 GLOBALS = None
 
 DEFAULT_LOG_STATUS = False
+DEFAULT_INFO_STATUS = False
+DEFAULT_STATUS_STATUS = False
 DEFAULT_SUCCESS_STATUS = False
 DEFAULT_SETTING_STATUS = False
 DEFAULT_DEBUG_STATUS = False
@@ -32,13 +34,13 @@ class Globals:
     EXTENSION = 'yml'
     LOCAL_CONFIGURATION_FILE_NAME = f'local-config{c.DOT}{EXTENSION}'
 
-    API_BACK_SLASH = f'api{OS_SEPARATOR}'
-    SRC_BACK_SLASH = f'src{OS_SEPARATOR}'
+    API_BACK_SLASH = f'api{EnvironmentHelper.OS_SEPARATOR}'
+    SRC_BACK_SLASH = f'src{EnvironmentHelper.OS_SEPARATOR}'
     BASE_API_PATH = f'{API_BACK_SLASH}{SRC_BACK_SLASH}'
 
-    RESOURCE_BACK_SLASH = f'resource{OS_SEPARATOR}'
-    REPOSITORY_BACK_SLASH = f'repository{OS_SEPARATOR}'
-    DEPENDENCY_BACK_SLASH = f'dependency{OS_SEPARATOR}'
+    RESOURCE_BACK_SLASH = f'resource{EnvironmentHelper.OS_SEPARATOR}'
+    REPOSITORY_BACK_SLASH = f'repository{EnvironmentHelper.OS_SEPARATOR}'
+    DEPENDENCY_BACK_SLASH = f'dependency{EnvironmentHelper.OS_SEPARATOR}'
 
     TOKEN_PIP_USER = '__TOKEN_PIP_USER__'
     SPACE_PIP_USER = f'{c.SPACE}--user'
@@ -78,14 +80,15 @@ class Globals:
     SAFE_AMOUNT_OF_TRIPLE_SINGLE_OR_DOUBLE_QUOTES_PLUS_ONE = 4
 
     LIB = 'lib'
-    STATIC_PACKAGE_PATH = f'{OS_SEPARATOR}statics'
-    TOKEN_PYTHON_VERSION = '__TOKEN_PYTHON_VERSION__'
-    HEROKU_PYTHON = f'{OS_SEPARATOR}lib{OS_SEPARATOR}python{TOKEN_PYTHON_VERSION}{OS_SEPARATOR}site-packages'
+
+    STATIC_PACKAGE_PATH = f'{EnvironmentHelper.OS_SEPARATOR}api{EnvironmentHelper.OS_SEPARATOR}resource'
 
     def __init__(self, filePath,
         loadLocalConfig = True,
         settingsFileName = APPLICATION,
         logStatus = DEFAULT_LOG_STATUS,
+        infoStatus = DEFAULT_INFO_STATUS,
+        statusStatus = DEFAULT_STATUS_STATUS,
         successStatus = DEFAULT_SUCCESS_STATUS,
         settingStatus = DEFAULT_SETTING_STATUS,
         debugStatus = DEFAULT_DEBUG_STATUS,
@@ -102,6 +105,8 @@ class Globals:
         if globalsInstanceIsNone() :
 
             self.logStatus = EnvironmentHelper.update(log.LOG, logStatus, default=DEFAULT_LOG_STATUS)
+            self.infoStatus = EnvironmentHelper.update(log.INFO, infoStatus, default=DEFAULT_INFO_STATUS)
+            self.statusStatus = EnvironmentHelper.update(log.STATUS, statusStatus, default=DEFAULT_STATUS_STATUS)
             self.successStatus = EnvironmentHelper.update(log.SUCCESS, successStatus, default=DEFAULT_SUCCESS_STATUS)
             self.settingStatus = EnvironmentHelper.update(log.SETTING, settingStatus, default=DEFAULT_SETTING_STATUS)
             self.debugStatus = EnvironmentHelper.update(log.DEBUG, debugStatus, default=DEFAULT_DEBUG_STATUS)
@@ -179,6 +184,9 @@ class Globals:
                 'warningStatus' : self.warningStatus,
                 'failureStatus' : self.failureStatus,
                 'errorStatus' : self.errorStatus,
+                'wrapperStatus': self.wrapperStatus,
+                'infoStatus' : self.infoStatus,
+                'statusStatus' : self.statusStatus,
                 'logStatus' : self.logStatus,
                 'globalsEverything' : self.globalsEverything,
                 'printRootPathStatus' : self.printRootPathStatus
@@ -194,26 +202,26 @@ class Globals:
 
     def buildApplicationPath(self):
         if ObjectHelper.isNotEmpty(self.filePath) :
-            self.currentPath = f'{str(Path(self.filePath).parent.absolute())}{self.OS_SEPARATOR}'
+            self.currentPath = f'{str(Path(self.filePath).parent.absolute())}{EnvironmentHelper.OS_SEPARATOR}'
         else :
-            self.currentPath = f'{str(Path(__file__).parent.absolute())}{self.OS_SEPARATOR}'
+            self.currentPath = f'{str(Path(__file__).parent.absolute())}{EnvironmentHelper.OS_SEPARATOR}'
         self.log(f'{self.__class__.__name__}{c.DOT}filePath: {self.filePath}')
         self.log(f'{self.__class__.__name__}{c.DOT}currentPath: {self.currentPath}')
 
         self.localPath = str(Path.home())
-        if not self.localPath[-1] == str(self.OS_SEPARATOR) :
-            self.localPath = f'{self.localPath}{self.OS_SEPARATOR}'
+        if not self.localPath[-1] == str(EnvironmentHelper.OS_SEPARATOR) :
+            self.localPath = f'{self.localPath}{EnvironmentHelper.OS_SEPARATOR}'
         self.log(f'{self.__class__.__name__}{c.DOT}localPath: {self.localPath}')
 
         self.baseApiPath = Globals.BASE_API_PATH
         self.apiPath = self.currentPath.split(self.baseApiPath)[0]
         self.log(f'{self.__class__.__name__}{c.DOT}apiPath: {self.apiPath}')
 
-        lastLocalPathPackage = self.localPath.split(self.OS_SEPARATOR)[-2]
-        firstBaseApiPath = self.baseApiPath.split(self.OS_SEPARATOR)[0]
+        lastLocalPathPackage = self.localPath.split(EnvironmentHelper.OS_SEPARATOR)[-2]
+        firstBaseApiPath = self.baseApiPath.split(EnvironmentHelper.OS_SEPARATOR)[0]
         lastLocalPathPackageNotFound = True
         self.apiPackage = c.NOTHING
-        for currentPackage in self.currentPath.split(self.OS_SEPARATOR) :
+        for currentPackage in self.currentPath.split(EnvironmentHelper.OS_SEPARATOR) :
             if lastLocalPathPackageNotFound :
                 if currentPackage == lastLocalPathPackage :
                     lastLocalPathPackageNotFound = False
@@ -235,12 +243,12 @@ class Globals:
 
     def getApiPath(self,apiPackageName):
         if not apiPackageName == c.NOTHING :
-             return f'{self.localPath}{self.apisRoot}{apiPackageName}{self.OS_SEPARATOR}'###-'{self.baseApiPath}'
+             return f'{self.localPath}{self.apisRoot}{apiPackageName}{EnvironmentHelper.OS_SEPARATOR}'###-'{self.baseApiPath}'
         if self.apisPath :
             return self.apisPath
         if self.localPath :
             return self.localPath
-        return f'{self.OS_SEPARATOR}'
+        return f'{EnvironmentHelper.OS_SEPARATOR}'
 
     def update(self) :
         self.updateDependencies()
@@ -299,7 +307,7 @@ class Globals:
         nodeSons = EnvironmentHelper.listDirectoryContent(path)
         for nodeSon in nodeSons :
             if self.nodeIsValid(nodeSon) :
-                nodeSonPath = f'{path}{self.OS_SEPARATOR}{nodeSon}'
+                nodeSonPath = f'{path}{EnvironmentHelper.OS_SEPARATOR}{nodeSon}'
                 try :
                     node[nodeSon] = self.makePathTreeVisible(nodeSonPath)
                 except :
@@ -312,7 +320,7 @@ class Globals:
         try :
             nodeSons = EnvironmentHelper.listDirectoryContent(nodePath)
             for nodeSon in nodeSons :
-                nodeSonPath = f'{nodePath}{self.OS_SEPARATOR}{nodeSon}'
+                nodeSonPath = f'{nodePath}{EnvironmentHelper.OS_SEPARATOR}{nodeSon}'
                 try :
                     node[nodeSon] = self.addNode(nodeSonPath)
                 except :
@@ -335,7 +343,7 @@ class Globals:
         nodeSons = EnvironmentHelper.listDirectoryContent(path)
         for nodeSon in nodeSons :
             if self.nodeIsValid(nodeSon) :
-                nodeSonPath = f'{path}{self.OS_SEPARATOR}{nodeSon}'
+                nodeSonPath = f'{path}{EnvironmentHelper.OS_SEPARATOR}{nodeSon}'
                 try :
                     node[nodeSon] = self.getPathTreeFromPath(nodeSonPath)
                 except : pass
@@ -343,9 +351,9 @@ class Globals:
 
     def overrideApiTree(self,apiName,package=None):
         if package :
-            actualPackage = package + self.OS_SEPARATOR
+            actualPackage = package + EnvironmentHelper.OS_SEPARATOR
         else :
-            actualPackage = apiName + self.OS_SEPARATOR
+            actualPackage = apiName + EnvironmentHelper.OS_SEPARATOR
         self.apiName = apiName
         self.apiPackage = package
         self.apiPath = f'{self.apisPath}{actualPackage}'
@@ -389,8 +397,8 @@ class Globals:
     def getSetting(self,nodeKey,settingTree=None) :
         if not settingTree :
             settingTree = self.settingTree
-        settingValue = SettingHelper.getSetting(nodeKey,self.settingTree)
-        if ObjectHelper.isEmpty(settingValue) or {} == settingValue :
+        settingValue = SettingHelper.getSetting(nodeKey,settingTree)
+        if ObjectHelper.isEmpty(settingValue):
             return SettingHelper.getSetting(nodeKey,self.defaultSettingTree)
         return settingValue
 
@@ -481,10 +489,9 @@ class Globals:
         self.log(f'Static package list: {StringHelper.prettyJson(site.getsitepackages())}')
         self.log(f'Static package (taken from application.yml): "{staticPackage}"')
         if ObjectHelper.isNone(staticPackage) :
-            staticPackage = f'{EnvironmentHelper.OS_SEPARATOR}api{EnvironmentHelper.OS_SEPARATOR}src{EnvironmentHelper.OS_SEPARATOR}resource'
+            staticPackage = str(self.STATIC_PACKAGE_PATH)
         self.setting(f'Static package: "{staticPackage}"')
         return staticPackage
-
         # staticPackage = self.getSetting(AttributeKey.PYTHON_STATIC_PACKAGE)
         # if ObjectHelper.isNone(staticPackage) :
         #     if EnvironmentHelper.isLinux() :
@@ -494,11 +501,11 @@ class Globals:
         #         staticPackageList = site.getsitepackages()
         #         self.log(f'Static packages list: {StringHelper.prettyJson(staticPackageList)}. Picking the first one')
         #         staticPackage = str(staticPackageList[0])
-        #     staticPackage = staticPackage.replace(f'{c.BACK_SLASH}{c.BACK_SLASH}',Globals.OS_SEPARATOR)
-        #     staticPackage = staticPackage.replace(c.BACK_SLASH,Globals.OS_SEPARATOR)
-        #     staticPackage = staticPackage.replace(f'{c.SLASH}{c.SLASH}',Globals.OS_SEPARATOR)
-        #     staticPackage = staticPackage.replace(c.SLASH,Globals.OS_SEPARATOR)
-        #     if staticPackage[-1] == str(Globals.OS_SEPARATOR) :
+        #     staticPackage = staticPackage.replace(f'{c.BACK_SLASH}{c.BACK_SLASH}',EnvironmentHelper.OS_SEPARATOR)
+        #     staticPackage = staticPackage.replace(c.BACK_SLASH,EnvironmentHelper.OS_SEPARATOR)
+        #     staticPackage = staticPackage.replace(f'{c.SLASH}{c.SLASH}',EnvironmentHelper.OS_SEPARATOR)
+        #     staticPackage = staticPackage.replace(c.SLASH,EnvironmentHelper.OS_SEPARATOR)
+        #     if staticPackage[-1] == str(EnvironmentHelper.OS_SEPARATOR) :
         #         staticPackage = staticPackage[:-1]
         #     herokuPythonLibPath = Globals.HEROKU_PYTHON.replace(Globals.TOKEN_PYTHON_VERSION, str(self.getSetting(AttributeKey.PYTHON_VERSION)))
         #     if staticPackage.endswith(herokuPythonLibPath) :
@@ -513,6 +520,14 @@ class Globals:
         if c.TRUE == self.logStatus :
             log.log(self.__class__,message,exception=exception)
 
+    def info(self,message,exception=None):
+        if c.TRUE == self.infoStatus :
+            log.info(self.__class__,message,exception=exception)
+
+    def status(self,message,exception=None):
+        if c.TRUE == self.statusStatus :
+            log.status(self.__class__,message,exception=exception)
+
     def debug(self,message):
         if c.TRUE == self.debugStatus :
             log.debug(self.__class__,message)
@@ -662,9 +677,9 @@ def importModule(resourceModuleName, muteLogs=False, reload=False, ignoreList=IG
                 log.log(importResource, f'Not possible to import "{resourceModuleName}" module. Going for a second attempt', exception=exception)
             try :
                 module = __import__(resourceModuleName)
-            except :
+            except Exception as innerException :
                 if not muteLogs :
-                    log.warning(importResource, f'Not possible to import "{resourceModuleName}" module in the second attempt either. Returning "{module}" by default', exception=exception)
+                    log.warning(importResource, f'Not possible to import "{resourceModuleName}" module in the second attempt either. Original cause: {str(exception)}. Returning "{module}" by default', exception=innerException)
         return module
 
 def importResource(resourceName, resourceModuleName=None, muteLogs=False, reload=False, ignoreList=IGNORE_REOURCE_LIST) :
